assert_operation_names

Function assert_operation_names 

pub async fn assert_operation_names(
    operations: &Arc<Mutex<Vec<OperationRecord>>>,
    expected: &[&str],
)
Assert the recorded operation names match (ignoring types).

A simplified version of assert_operations that checks only the operation names without the "type:" prefix.

Panics

Panics with a diff if the name sequences don’t match.

Examples

use durable_lambda_testing::prelude::*;

let (mut ctx, _calls, ops) = MockDurableContext::new()
    .build()
    .await;

let _: Result<i32, String> = ctx.step("validate", || async { Ok(42) }).await.unwrap();

assert_operation_names(&ops, &["validate"]).await;