Module prelude

Module prelude 

User-facing test re-exports for durable Lambda testing.

Single import for everything needed to write durable Lambda tests:

use durable_lambda_testing::prelude::*;

This re-exports:

Re-exports

pub use crate::assertions::assert_checkpoint_count;
pub use crate::assertions::assert_no_checkpoints;
pub use crate::assertions::assert_operation_count;
pub use crate::assertions::assert_operation_names;
pub use crate::assertions::assert_operations;
pub use crate::mock_backend::BatchCallCounter;
pub use crate::mock_backend::CheckpointCall;
pub use crate::mock_backend::CheckpointRecorder;
pub use crate::mock_backend::MockBackend;
pub use crate::mock_backend::OperationRecord;
pub use crate::mock_backend::OperationRecorder;
pub use crate::mock_context::MockDurableContext;

Structs

DurableContext
Main context for a durable execution invocation.
StepOptions
Configure retry behavior for step operations.

Enums

DurableError
Represent all errors that can occur within the durable-lambda SDK.
ExecutionMode
Signal whether the replay engine is replaying from history or executing new operations.