User-facing test re-exports for durable Lambda testing.
Single import for everything needed to write durable Lambda tests:
use durable_lambda_testing::prelude::*;This re-exports:
MockDurableContext— builder for creating mock contexts with pre-loaded resultsMockBackendandCheckpointCall— mock backend and checkpoint recording- Assertion helpers:
assert_checkpoint_count,assert_no_checkpoints - Core types:
DurableContext,DurableError,StepOptions,ExecutionMode
Re-exports
pub use crate::assertions::assert_checkpoint_count;pub use crate::assertions::assert_no_checkpoints;pub use crate::assertions::assert_operation_count;pub use crate::assertions::assert_operation_names;pub use crate::assertions::assert_operations;pub use crate::mock_backend::BatchCallCounter;pub use crate::mock_backend::CheckpointCall;pub use crate::mock_backend::CheckpointRecorder;pub use crate::mock_backend::MockBackend;pub use crate::mock_backend::OperationRecord;pub use crate::mock_backend::OperationRecorder;pub use crate::mock_context::MockDurableContext;
Structs
- Durable
Context - Main context for a durable execution invocation.
- Step
Options - Configure retry behavior for step operations.
Enums
- Durable
Error - Represent all errors that can occur within the durable-lambda SDK.
- Execution
Mode - Signal whether the replay engine is replaying from history or executing new operations.